@@ -2,7 +2,7 @@
 """
 :Author: CaiYouBin
 :Date: 2020-05-12 20:04:54
-@LastEditTime: 2022-07-22 15:53:32
+@LastEditTime: 2022-07-26 18:57:44
 @LastEditors: HuangJianYi
 :description: 基础接口
 """
@@ -100,8 +100,8 @@ class ActCreateHandler(TopBaseHandler):
                 "ruleDetail": "1、本产品为在线体验商品，用户购买盲盒机次数完成在线拆盲盒（即明确盲盒内具体商品）后，即为消费完成，仓库根据用户抽取的确认款直接发货。\n" + "2、在线打开盲盒明确具体款式后，不接受任何理由退换货\n" + "3、若出现产品质量问题等。本单品一样享受售后换货流程\n" + "4、在一次抽奖中，该盲盒中不会抽到重复的商品【多次抽有可能重复】【重复指的是完全一样的商品】\n" + "5、由于盲盒的特殊性，不参加店内其他活动\n" + "6、盲盒会不定期更新，具体以该盲盒商品池中显示的商品为准\n" + "7、如果您愿意拍下，就是认同我们的活动规则，介意者也不勉强，可以自由选择关闭页面或者浏览我们的其他商品\n" + "8、本活动最终解释权归XXXX所有\n"
             }]
             act_info.rule_desc = self.json_dumps(act_info.rule_desc)
-            act_info.start_date = "2020-02-25 00:00:00"
-            act_info.end_date = "2100-02-25 00:00:00"
+            act_info.start_date = self.get_now_datetime()
+            act_info.end_date = "2050-02-25 00:00:00"
             act_info.is_black = 0
             act_info.is_release = 1
             act_info.index_desc = {"index_pic_istemplate": 0, "index_pic": [{"url": "https://isv.alibabausercontent.com/010230116422/imgextra/i4/2206353354303/O1CN0164WKym1heosiC9by5_!!2206353354303-2-isvtu-010230116422.png"}], "index_notice": "选一个喜欢的系列试试吧~抽盒次数购买后概不退款~"}
@@ -402,7 +402,7 @@ class ActListHandler(SevenBaseHandler):
 
         app_id = self.get_app_id()
         if app_id:
-            order_by = "id ASC"
+            order_by = "id desc"
             condition = "app_id=%s"
             if is_del == 0:
                 condition += "AND is_del=0"
